@@ -15,13 +15,13 @@ Inspired by [abersheeran/only-pipe](https://github.com/abersheeran/only-pipe) ,
     pip install pipeit
 
 ## Usage
-- Statements start with `PIPE` and end with `END`.
+- Statements start with `PIPE` and end with `END` **OR** you can even ellipsis them.
 - There're only two objects(`PIPE` & `END`) and three types(`Filter` ,`Map` & `Reduce`) in namespace, so feel free to use `from pipeit import *`.
-- Convert filter into tuple , e.g. `map(lambda x:x + 1) => (map , lambda x:x + 1)`
+- Convert filter into tuple or capital the first letter, e.g. `map(lambda x:x + 1) => (map , lambda x:x + 1)` or `Map(lambda x:x + 1)` , however **DO NOT MIX USE THEM**.
+- It'll be 10% ~ 20% faster using the original python functional way than using these wrappers.
 
 ## Example
 
-Some description.
 ```Python
 >>> from pipit import PIPE , END , Map , Filter , Reduce
 
@@ -48,15 +48,17 @@ Some description.
 ```
 """
 __author__ = 'WEN (github.com/GoodManWEN)'
-__version__ = '0.1.4'
+__version__ = '0.1.5'
 
 from .utils import *
 from .wrapper import *
+from .timer import timeit
 
 __all__ = (
+    'timeit',
     'PIPE',
     'END',
     'Filter',
     'Map',
     'Reduce'
-)
\ No newline at end of file
+)
